/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_ACCT_TUNNEL_CONNECTION 68
#define PW_ACCT_TUNNEL_PACKETS_LOST 86

#define PW_ACCT_STATUS_TYPE_TUNNEL_START 9
#define PW_ACCT_STATUS_TYPE_TUNNEL_STOP 10
#define PW_ACCT_STATUS_TYPE_TUNNEL_REJECT 11
#define PW_ACCT_STATUS_TYPE_TUNNEL_LINK_START 12
#define PW_ACCT_STATUS_TYPE_TUNNEL_LINK_STOP 13
#define PW_ACCT_STATUS_TYPE_TUNNEL_LINK_REJECT 14
