/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_FRAG_STATUS 241.1
#define PW_PROXY_STATE_LENGTH 241.2

#define PW_FRAG_STATUS_RESERVED 0
#define PW_FRAG_STATUS_FRAGMENTATION_SUPPORTED 1
#define PW_FRAG_STATUS_MORE_DATA_PENDING 2
#define PW_FRAG_STATUS_MORE_DATA_REQUEST 3
