/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_EGRESS_VLANID 56
#define PW_INGRESS_FILTERS 57
#define PW_EGRESS_VLAN_NAME 58
#define PW_USER_PRIORITY_TABLE 59

#define PW_INGRESS_FILTERS_ENABLED 1
#define PW_INGRESS_FILTERS_DISABLED 2
