/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_ERROR_CAUSE 101

#define PW_SERVICE_TYPE_AUTHORIZE_ONLY 17
#define PW_ERROR_CAUSE_RESIDUAL_CONTEXT_REMOVED 201
#define PW_ERROR_CAUSE_INVALID_EAP_PACKET 202
#define PW_ERROR_CAUSE_UNSUPPORTED_ATTRIBUTE 401
#define PW_ERROR_CAUSE_MISSING_ATTRIBUTE 402
#define PW_ERROR_CAUSE_NAS_IDENTIFICATION_MISMATCH 403
#define PW_ERROR_CAUSE_INVALID_REQUEST 404
#define PW_ERROR_CAUSE_UNSUPPORTED_SERVICE 405
#define PW_ERROR_CAUSE_UNSUPPORTED_EXTENSION 406
#define PW_ERROR_CAUSE_INVALID_ATTRIBUTE_VALUE 407
#define PW_ERROR_CAUSE_ADMINISTRATIVELY_PROHIBITED 501
#define PW_ERROR_CAUSE_PROXY_REQUEST_NOT_ROUTABLE 502
#define PW_ERROR_CAUSE_SESSION_CONTEXT_NOT_FOUND 503
#define PW_ERROR_CAUSE_SESSION_CONTEXT_NOT_REMOVABLE 504
#define PW_ERROR_CAUSE_PROXY_PROCESSING_ERROR 505
#define PW_ERROR_CAUSE_RESOURCES_UNAVAILABLE 506
#define PW_ERROR_CAUSE_REQUEST_INITIATED 507
