/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_EAP_LOWER_LAYER 163

#define PW_EAP_LOWER_LAYER_WIRED_IEEE_802_1X 1
#define PW_EAP_LOWER_LAYER_IEEE_802_1X_NO_PREAUTH 2
#define PW_EAP_LOWER_LAYER_IEEE_802_1X_PREAUTH 3
#define PW_EAP_LOWER_LAYER_IEEE_802_16E 4
#define PW_EAP_LOWER_LAYER_IKEV2 5
#define PW_EAP_LOWER_LAYER_PPP 6
#define PW_EAP_LOWER_LAYER_PANA_NO_PREAUTH 7
#define PW_EAP_LOWER_LAYER_GSS_API 8
#define PW_EAP_LOWER_LAYER_PANA_PREAUTH 9
