/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_FRAMED_MANAGEMENT 133
#define PW_MANAGEMENT_TRANSPORT_PROTECTION 134
#define PW_MANAGEMENT_POLICY_ID 135
#define PW_MANAGEMENT_PRIVILEGE_LEVEL 136

#define PW_SERVICE_TYPE_FRAMED_MANAGEMENT 18
#define PW_FRAMED_MANAGEMENT_SNMP 1
#define PW_FRAMED_MANAGEMENT_WEB_BASED 2
#define PW_FRAMED_MANAGEMENT_NETCONF 3
#define PW_FRAMED_MANAGEMENT_FTP 4
#define PW_FRAMED_MANAGEMENT_TFTP 5
#define PW_FRAMED_MANAGEMENT_SFTP 6
#define PW_FRAMED_MANAGEMENT_RCP 7
#define PW_FRAMED_MANAGEMENT_SCP 8
#define PW_MANAGEMENT_TRANSPORT_PROTECTION_NO_PROTECTION 1
#define PW_MANAGEMENT_TRANSPORT_PROTECTION_INTEGRITY_PROTECTION 2
#define PW_MANAGEMENT_TRANSPORT_PROTECTION_INTEGRITY_CONFIDENTIALITY_PROTECTION 3
